# Hyde Park Purse snatching example
#
# The file replications the Hyde Park purse snatching
# intervention analysis reported in Brandt and Williams. 2001
# "A Linear Poisson Autoregressive Model: the PAR(p)"
# Political Analysis 9(2): 164-184.
#
# See http://www.psci.unt.edu/~brandt/ects/hydepark.pdf for comparison
# with the original results published results produced using GAUSS.
#
# Patrick Brandt
#
# brandt@unt.edu
# Department of Political Science
# University of North Texas
#
# This file contains no warranty or guarantee of performance.
# Use at your own risk for non commercial use
#
# December 2001: This file replicates the analysis in Brandt and
# Williams in R 1.3.1

source("pests.r")

# Set up data matrices 
HydePark <- read.table(file = "hydepark.txt", header=F,
                      col.names=c("Snatched.Purses"))

whistle <- c(rep(0,41),rep(1,30))
x <- matrix(cbind(rep(1,71),whistle), ncol=2)
colnames(x) <- c("Constant","Whistle")

# Do a Poisson regression to get some consistent starting values
HydePark.Poisson <- glm(HydePark$Snatched.Purses ~ whistle, family=poisson)
summary(HydePark.Poisson)

# Now use the Poisson results to start the PAR(p) models
HydePark.PAR1 <- Parp(y=HydePark$Snatched.Purses,x=x,
                       init.param=c(0.1,HydePark.Poisson$coefficients))

HydePark.PAR2 <- Parp(y=HydePark$Snatched.Purses,x=x,
                      init.param=c(0.1,0,HydePark.Poisson$coefficients))

# Now use the Poisson results to start a PEWMA model
HydePark.Pewma <- Pewma(y=HydePark$Snatched.Purses, x=as.matrix(whistle),
                        init.param=c(0.8,HydePark.Poisson$coefficients[2]))


