# pests-example.r
#
# A simple example file for the PESTS source file.
#
# Patrick Brandt
#
# brandt@unt.edu
# Department of Political Science
# University of North Texas
#
# This file contains no warranty or guarantee of performance.
# Use at your own risk for non commercial use
#

source("pests.r")

# Simulate some data.
#
#
# Generic parameters for the simulation....
#
n <- 200                                  # Number of observations
x <- sqrt(0.5)*matrix(rnorm(n),ncol=1)    # Generic matrix of regressors

# PEWMA DGP parameters
#
# Prior mean for DGP is a0/b0 
a0 <- 5            # Prior for a_t
b0 <- 0.5          # Prior for b_t
w <- 0.5           # Omega, the EWMA parameter
d.pewma <- c(0.5)  # Delta, coefficent(s) on regressors

y.pewma <- pewmadgp(n,a0,b0,w,x,d.pewma)

# PAR(1) DGP parameters
#
rho <- 0.5           # AR(1) coefficient
d.par1 <- c(1,0.5)   # Regressors (constant and coefficient)
y.par1 <- parpdgp(n,rho,x=matrix(cbind(rep(1,100),x)),d.par1)


# Plot the results of the dgps
# Note the trick to get Barlett corrected std errors on the ACFs

par(mfcol=c(2,2))

plot(y.pewma,ylab="Count", main="PEWMA data")
acftmp <- acf(y.pewma,plot=F)
plot(acftmp,ci.type=c("ma"),
          ci=0.9, xlab = "Lag",main="PEWMA data ACF")

plot(y.par1,ylab="Count", main="PAR(1) data")
acftmp <- acf(y.par1,plot=F)
plot(acftmp,ci.type=c("ma"),
          ci=0.9, xlab = "Lag", main="PAR(1) data ACF")


# Run some models for comparisons.....
# Use the mnemonic of "dgp.estimator" to keep straight what we are
# doing....

pewma.Poisson <- glm(y.pewma~x, family=poisson)
summary(pewma.Poisson)
par1.Poisson <- glm(y.par1~x, family=poisson)
summary(par1.Poisson)

# Now use the Poisson results to start the PESTS models
pewma.PEWMA <- Pewma(y=y.pewma, x=x,
                     init.param=c(0.5,pewma.Poisson$coefficients[2]))

par1.PAR1 <- Parp(y=y.par1,x=matrix(cbind(rep(1,n),x)),
                  init.param=c(0,par1.Poisson$coefficients))






